@@ -122,7 +122,7 @@ impl Ipv4Header {
 
     /// Renamed to `Ipv4Header::from_slice`
     #[deprecated(
-        since = "0.10.0",
+        since = "0.10.1",
         note = "Renamed to `Ipv4Header::from_slice`"
     )]
     #[inline]
@@ -351,6 +351,16 @@ impl Ipv4Header {
         .ones_complement()
         .to_be()
     }
+
+    /// Returns true if the payload is fragmented.
+    ///
+    /// Either data is missing (more_fragments set) or there is
+    /// an fragment offset.
+    #[inline]
+    pub fn is_fragmenting_payload(&self) -> bool {
+        self.more_fragments ||
+        (0 != self.fragments_offset)
+    }
 }
 
 //NOTE: I would have prefered to NOT write my own Default, Debug & PartialEq implementation but there are no
@@ -684,6 +694,16 @@ impl<'a> Ipv4HeaderSlice<'a> {
         }
     }
 
+    /// Returns true if the payload is fragmented.
+    ///
+    /// Either data is missing (more_fragments set) or there is
+    /// an fragment offset.
+    #[inline]
+    pub fn is_fragmenting_payload(&self) -> bool {
+        self.more_fragments() ||
+        (0 != self.fragments_offset())
+    }
+
     /// Decode all the fields and copy the results to a Ipv4Header struct
     pub fn to_header(&self) -> Ipv4Header {
         let options = self.options();
